@@ -4,26 +4,13 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-state $Indicators = __PACKAGE__->INDICATORS;
-state $ReBackbone = qr<^Content-Type:[ ](?:message/rfc822|text/rfc822-headers)>m;
-state $MarkingsOf = {
-    'message' => qr/\A[*][*][ ].+[ ][*][*]\z/,
-    'error'   => qr/\AThe[ ]response([ ]from[ ]the[ ]remote[ ]server)?[ ]was:\z/,
-    'html'    => qr{\AContent-Type:[ ]*text/html;[ ]*charset=['"]?(?:UTF|utf)[-]8['"]?\z},
-};
-state $MessagesOf = {
-    'userunknown'  => ["because the address couldn't be found. Check for typos or unnecessary spaces and try again."],
-    'notaccept'    => ['Null MX'],
-    'networkerror' => [' had no relevant answers.', ' responded with code NXDOMAIN'],
-};
-
 sub description { 'G Suite: https://gsuite.google.com/' }
-sub make {
+sub inquire {
     # Detect an error from G Suite (Transfer from G Suite to a destination host)
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [Undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to parse or the arguments are missing
     # @since v4.21.0
     my $class = shift;
     my $mhead = shift // return undef;
@@ -33,12 +20,22 @@ sub make {
     return undef unless index($mhead->{'subject'}, 'Delivery Status Notification') > -1;
     return undef unless $mhead->{'x-gm-message-state'};
 
-    require Sisimai::RFC1894;
+    state $indicators = __PACKAGE__->INDICATORS;
+    state $boundaries = ['Content-Type: message/rfc822', 'Content-Type: text/rfc822-headers'];
+    state $markingsof = {
+        'message' => ['** '],
+        'error'   => ['The response was:', 'The response from the remote server was:'],
+    };
+    state $messagesof = {
+        'userunknown'  => ["because the address couldn't be found. Check for typos or unnecessary spaces and try again."],
+        'notaccept'    => ['Null MX'],
+        'networkerror' => [' had no relevant answers.', ' responded with code NXDOMAIN'],
+    };
+
     my $fieldtable = Sisimai::RFC1894->FIELDTABLE;
     my $permessage = {};    # (Hash) Store values of each Per-Message field
-
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $ReBackbone);
+    my $emailparts = Sisimai::RFC5322->part($mbody, $boundaries);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $endoferror = 0;     # (Integer) Flag for a blank line after error messages
@@ -48,14 +45,14 @@ sub make {
     };
     my $v = undef;
 
-    for my $e ( split("\n", $emailsteak->[0]) ) {
-        # Read error messages and delivery status lines from the head of the email
-        # to the previous line of the beginning of the original message.
+    for my $e ( split("\n", $emailparts->[0]) ) {
+        # Read error messages and delivery status lines from the head of the email to the previous
+        # line of the beginning of the original message.
         unless( $readcursor ) {
             # Beginning of the bounce message or message/delivery-status part
-            $readcursor |= $Indicators->{'deliverystatus'} if $e =~ $MarkingsOf->{'message'};
+            $readcursor |= $indicators->{'deliverystatus'} if grep { index($e, $_) == 0 } $markingsof->{'message'}->@*;
         }
-        next unless $readcursor & $Indicators->{'deliverystatus'};
+        next unless $readcursor & $indicators->{'deliverystatus'};
 
         if( my $f = Sisimai::RFC1894->match($e) ) {
             # $e matched with any field defined in RFC3464
@@ -89,6 +86,11 @@ sub make {
                 next unless exists $fieldtable->{ $o->[0] };
                 $v->{ $fieldtable->{ $o->[0] } } = $o->[2];
 
+                if( $fieldtable->{ $o->[0] } eq 'lhost' ) {
+                    # Do not set an email address as a hostname in "lhost" value
+                    $v->{'lhost'} = '' if index($v->{'lhost'}, '@');
+                }
+
                 next unless $f == 1;
                 $permessage->{ $fieldtable->{ $o->[0] } } = $o->[2];
             }
@@ -100,9 +102,9 @@ sub make {
                 next if $endoferror;
                 $v->{'diagnosis'} .= $e;
 
-            } elsif( $e =~ $MarkingsOf->{'error'} ) {
+            } elsif( grep { index($e, $_) == 0 } $markingsof->{'error'}->@* ) {
                 # The response from the remote server was:
-                $anotherset->{'diagnosis'} .= $e;
+                $anotherset->{'diagnosis'} .= ' '.$e;
 
             } else {
                 # ** Address not found **
@@ -112,10 +114,9 @@ sub make {
                 #
                 # The response from the remote server was:
                 # 550 #5.1.0 Address rejected.
-                next if $e =~ /\AContent-Type:/;
+                next if index($e, 'Content-Type:') == 0;
                 if( $anotherset->{'diagnosis'} ) {
-                    # Continued error messages from the previous line like
-                    # "550 #5.1.0 Address rejected."
+                    # Continued error messages from the previous line like "550 #5.1.0 Address rejected."
                     next if $emptylines > 5;
                     unless( length $e ) {
                         # Count and next()
@@ -129,7 +130,7 @@ sub make {
                     #
                     # Your message wasn't delivered to * because the address couldn't be found.
                     # Check for typos or unnecessary spaces and try again.
-                    next unless $e =~ $MarkingsOf->{'message'};
+                    next unless grep { index($e, $_) == 0 } $markingsof->{'message'}->@*;
                     $anotherset->{'diagnosis'} = $e;
                 }
             }
@@ -145,7 +146,7 @@ sub make {
         if( exists $anotherset->{'diagnosis'} && $anotherset->{'diagnosis'} ) {
             # Copy alternative error message
             $e->{'diagnosis'} ||= $anotherset->{'diagnosis'};
-            if( $e->{'diagnosis'} =~ /\A\d+\z/ ) {
+            if( index($e->{'diagnosis'}, ' ') < 0 && int($e->{'diagnosis'}) > 0 ) {
                 # Override the value of diagnostic code message
                 $e->{'diagnosis'} = $anotherset->{'diagnosis'};
 
@@ -180,14 +181,14 @@ sub make {
         }
         $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'});
 
-        for my $q ( keys %$MessagesOf ) {
+        for my $q ( keys %$messagesof ) {
             # Guess an reason of the bounce
-            next unless grep { index($e->{'diagnosis'}, $_) > -1 } @{ $MessagesOf->{ $q } };
+            next unless grep { index($e->{'diagnosis'}, $_) > -1 } $messagesof->{ $q }->@*;
             $e->{'reason'} = $q;
             last;
         }
     }
-    return { 'ds' => $dscontents, 'rfc822' => $emailsteak->[1] };
+    return { 'ds' => $dscontents, 'rfc822' => $emailparts->[1] };
 }
 
 1;
@@ -205,8 +206,8 @@ Sisimai::Lhost::GSuite - bounce mail parser class for C<G Suite>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::GSuite parses a bounce email which created by C<G Suite>.
-Methods in the module are called from only Sisimai::Message.
+Sisimai::Lhost::GSuite parses a bounce email which created by C<G Suite>. Methods in the module are
+called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
@@ -216,10 +217,10 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::GSuite->description;
 
-=head2 C<B<make(I<header data>, I<reference to body string>)>>
+=head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<make()> method parses a bounced email and return results as a array reference.
-See Sisimai::Message for more details.
+C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
+for more details.
 
 =head1 AUTHOR
 
@@ -227,7 +228,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2017-2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2017-2023 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
