@@ -4,28 +4,13 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-state $Indicators = __PACKAGE__->INDICATORS;
-state $ReBackbone = qr|^Content-Type:[ ]message/rfc822|m;
-state $MarkingsOf = {
-    'message' => qr/\AYour[ ]mail[ ](?:
-         sent[ ]on:?[ ][A-Z][a-z]{2}[,]
-        |attempted[ ]to[ ]be[ ]delivered[ ]on:?[ ][A-Z][a-z]{2}[,]
-        )
-    /x,
-};
-state $MessagesOf = {
-    'mailboxfull' => ['As their mailbox is full'],
-    'norelaying'  => ['Due to the following SMTP relay error'],
-    'hostunknown' => ['As the remote domain doesnt exist'],
-};
-
 sub description { 'au by KDDI: https://www.au.kddi.com' }
-sub make {
+sub inquire {
     # Detect an error from au by KDDI
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [Undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to parse or the arguments are missing
     # @since v4.0.0
     my $class = shift;
     my $mhead = shift // return undef;
@@ -33,30 +18,39 @@ sub make {
     my $match = 0;
 
     # 'message-id' => qr/[@].+[.]ezweb[.]ne[.]jp[>]\z/,
-    $match ||= 1 if $mhead->{'from'} =~ /no-reply[@].+[.]dion[.]ne[.]jp/;
+    $match ||= 1 if Sisimai::String->aligned(\$mhead->{'from'}, ['no-reply@.', '.dion.ne.jp']);
     $match ||= 1 if $mhead->{'reply-to'} && $mhead->{'reply-to'} eq 'no-reply@app.auone-net.jp';
-    $match ||= 1 if grep { rindex($_, 'ezweb.ne.jp (') > -1 } @{ $mhead->{'received'} };
-    $match ||= 1 if grep { rindex($_, '.au.com (') > -1 } @{ $mhead->{'received'} };
+    $match ||= 1 if grep { rindex($_, 'ezweb.ne.jp (') > -1 } $mhead->{'received'}->@*;
+    $match ||= 1 if grep { rindex($_, '.au.com (') > -1 } $mhead->{'received'}->@*;
     return undef unless $match;
 
+    state $indicators = __PACKAGE__->INDICATORS;
+    state $boundaries = ['Content-Type: message/rfc822'];
+    state $markingsof = { 'message' => ['Your mail sent on:', 'Your mail attempted to be delivered on:'] };
+    state $messagesof = {
+        'mailboxfull' => ['As their mailbox is full'],
+        'norelaying'  => ['Due to the following SMTP relay error'],
+        'hostunknown' => ['As the remote domain doesnt exist'],
+    };
+
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $ReBackbone);
+    my $emailparts = Sisimai::RFC5322->part($mbody, $boundaries);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $v = undef;
 
-    for my $e ( split("\n", $emailsteak->[0]) ) {
-        # Read error messages and delivery status lines from the head of the email
-        # to the previous line of the beginning of the original message.
+    for my $e ( split("\n", $emailparts->[0]) ) {
+        # Read error messages and delivery status lines from the head of the email to the previous
+        # line of the beginning of the original message.
         unless( $readcursor ) {
             # Beginning of the bounce message or message/delivery-status part
-            $readcursor |= $Indicators->{'deliverystatus'} if $e =~ $MarkingsOf->{'message'};
+            $readcursor |= $indicators->{'deliverystatus'} if grep { index($e, $_) == 0 } $markingsof->{'message'}->@*;
         }
-        next unless $readcursor & $Indicators->{'deliverystatus'};
+        next unless $readcursor & $indicators->{'deliverystatus'};
         next unless length $e;
 
         $v = $dscontents->[-1];
-        if( $e =~ /\A[ \t]+Could not be delivered to: [<]([^ ]+[@][^ ]+)[>]/ ) {
+        if( index($e, ' Could not be delivered to: <') > -1 ) {
             # Your mail sent on: Thu, 29 Apr 2010 11:04:47 +0900
             #     Could not be delivered to: <******@**.***.**>
             #     As their mailbox is full.
@@ -66,24 +60,26 @@ sub make {
                 $v = $dscontents->[-1];
             }
 
-            my $r = Sisimai::Address->s3s4($1);
-            next unless Sisimai::RFC5322->is_emailaddress($r);
+            my $r = Sisimai::Address->s3s4(substr($e, index($e, '<') + 1, ));
+            next unless Sisimai::Address->is_emailaddress($r);
             $v->{'recipient'} = $r;
             $recipients++;
 
-        } elsif( $e =~ /Your mail sent on: (.+)\z/ ) {
+        } elsif( index($e, 'Your mail sent on: ') > -1 ) {
             # Your mail sent on: Thu, 29 Apr 2010 11:04:47 +0900
-            $v->{'date'} = $1;
+            $v->{'date'} = substr($e, 19, );
 
         } else {
             #     As their mailbox is full.
-            $v->{'diagnosis'} .= $e.' ' if $e =~ /\A[ \t]+/;
+            $v->{'diagnosis'} .= $e.' ' if index($e, ' ') == 0;
         }
     }
     return undef unless $recipients;
 
+    require Sisimai::SMTP::Command;
     for my $e ( @$dscontents ) {
         $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'});
+        $e->{'command'}   = Sisimai::SMTP::Command->find($e->{'diagnosis'}) || '';
 
         if( defined $mhead->{'x-spasign'} && $mhead->{'x-spasign'} eq 'NG' ) {
             # Content-Type: text/plain; ..., X-SPASIGN: NG (spamghetti, au by KDDI)
@@ -92,22 +88,21 @@ sub make {
 
         } else {
             if( $e->{'command'} eq 'RCPT' ) {
-                # set "userunknown" when the remote server rejected after RCPT
-                # command.
+                # set "userunknown" when the remote server rejected after RCPT command.
                 $e->{'reason'} = 'userunknown';
 
             } else {
                 # SMTP command is not RCPT
-                SESSION: for my $r ( keys %$MessagesOf ) {
+                SESSION: for my $r ( keys %$messagesof ) {
                     # Verify each regular expression of session errors
-                    next unless grep { index($e->{'diagnosis'}, $_) > -1 } @{ $MessagesOf->{ $r } };
+                    next unless grep { index($e->{'diagnosis'}, $_) > -1 } $messagesof->{ $r }->@*;
                     $e->{'reason'} = $r;
                     last;
                 }
             }
         }
     }
-    return { 'ds' => $dscontents, 'rfc822' => $emailsteak->[1] };
+    return { 'ds' => $dscontents, 'rfc822' => $emailparts->[1] };
 }
 
 1;
@@ -124,8 +119,8 @@ Sisimai::Lhost::KDDI - bounce mail parser class for C<au by KDDI>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::KDDI parses a bounce email which created by C<au by KDDI>.
-Methods in the module are called from only Sisimai::Message.
+Sisimai::Lhost::KDDI parses a bounce email which created by C<au by KDDI>. Methods in the module are
+called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
@@ -135,10 +130,10 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::KDDI->description;
 
-=head2 C<B<make(I<header data>, I<reference to body string>)>>
+=head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<make()> method parses a bounced email and return results as a array reference.
-See Sisimai::Message for more details.
+C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
+for more details.
 
 =head1 AUTHOR
 
@@ -146,7 +141,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2023 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
