@@ -5,12 +5,12 @@ use strict;
 use warnings;
 
 sub description { 'McAfee Email Appliance' }
-sub make {
+sub inquire {
     # Detect an error from McAfee
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [Undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to parse or the arguments are missing
     # @since v4.1.1
     my $class = shift;
     my $mhead = shift // return undef;
@@ -22,31 +22,22 @@ sub make {
     return undef unless $mhead->{'subject'} eq 'Delivery Status';
 
     state $indicators = __PACKAGE__->INDICATORS;
-    state $rebackbone = qr|^Content-Type:[ ]message/rfc822|m;
+    state $boundaries = ['Content-Type: message/rfc822'];
     state $startingof = { 'message' => ['--- The following addresses had delivery problems ---'] };
-    state $refailures = {
-        'userunknown' => qr{(?:
-             [ ]User[ ][(].+[@].+[)][ ]unknown[.][ ]
-            |550[ ]Unknown[ ]user[ ][^ ]+[@][^ ]+
-            |550[ ][<].+?[@].+?[>][.]+[ ]User[ ]not[ ]exist
-            |No[ ]such[ ]user
-            )
-        }x,
-    };
+    state $messagesof = { 'userunknown' => [' User not exist', ' unknown.', '550 Unknown user ', 'No such user'] };
 
-    require Sisimai::RFC1894;
     my $fieldtable = Sisimai::RFC1894->FIELDTABLE;
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $rebackbone);
+    my $emailparts = Sisimai::RFC5322->part($mbody, $boundaries);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
-    my $diagnostic = '';    # (String) Alternative diagnostic message
+    my $issuedcode = '';    # (String) Alternative diagnostic message
     my $v = undef;
     my $p = '';
 
-    for my $e ( split("\n", $emailsteak->[0]) ) {
-        # Read error messages and delivery status lines from the head of the email
-        # to the previous line of the beginning of the original message.
+    for my $e ( split("\n", $emailparts->[0]) ) {
+        # Read error messages and delivery status lines from the head of the email to the previous
+        # line of the beginning of the original message.
         unless( $readcursor ) {
             # Beginning of the bounce message or message/delivery-status part
             $readcursor |= $indicators->{'deliverystatus'} if index($e, $startingof->{'message'}->[0]) > -1;
@@ -66,15 +57,15 @@ sub make {
         #
         $v = $dscontents->[-1];
 
-        if( $e =~ /\A[<]([^ ]+[@][^ ]+)[>][ \t]+[(](.+)[)]\z/ ) {
+        if( Sisimai::String->aligned(\$e, ['<', '@', '>', '(', ')']) ) {
             # <kijitora@example.co.jp>   (Unknown user kijitora@example.co.jp)
             if( $v->{'recipient'} ) {
                 # There are multiple recipient addresses in the message body.
                 push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
                 $v = $dscontents->[-1];
             }
-            $v->{'recipient'} = $1;
-            $diagnostic = $2;
+            $v->{'recipient'} = Sisimai::Address->s3s4(substr($e, index($e, '<'), index($e, '>')));
+            $issuedcode = substr($e, index($e, '(') + 1,);
             $recipients++;
 
         } elsif( my $f = Sisimai::RFC1894->match($e) ) {
@@ -82,8 +73,10 @@ sub make {
             my $o = Sisimai::RFC1894->field($e);
             unless( $o ) {
                 # Fallback code for empty value or invalid formatted value
-                # - Original-Recipient: <kijitora@example.co.jp>
-                $v->{'alias'} = Sisimai::Address->s3s4($1) if $e =~ /\AOriginal-Recipient:[ ]*([^ ]+)\z/;
+                if( index($e, 'Original-Recipient: ') == 0 ) {
+                    # - Original-Recipient: <kijitora@example.co.jp>
+                    $v->{'alias'} = Sisimai::Address->s3s4(substr($e, index($e, ':') + 1,));
+                }
                 next;
             }
             next unless exists $fieldtable->{ $o->[0] };
@@ -92,9 +85,9 @@ sub make {
         } else {
             # Continued line of the value of Diagnostic-Code field
             next unless index($p, 'Diagnostic-Code:') == 0;
-            next unless $e =~ /\A[ \t]+(.+)\z/;
-            $v->{'diagnosis'} .= ' '.$1;
-        } # End of error message part
+            next unless index($e, ' ');
+            $v->{'diagnosis'} .= ' '.Sisimai::String->sweep($e);
+        }
     } continue {
         # Save the current line for the next loop
         $p = $e;
@@ -102,16 +95,16 @@ sub make {
     return undef unless $recipients;
 
     for my $e ( @$dscontents ) {
-        $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'} || $diagnostic);
+        $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'} || $issuedcode );
 
-        SESSION: for my $r ( keys %$refailures ) {
+        SESSION: for my $r ( keys %$messagesof ) {
             # Verify each regular expression of session errors
-            next unless $e->{'diagnosis'} =~ $refailures->{ $r };
+            next unless grep { index($e->{'diagnosis'}, $_) > -1 } $messagesof->{ $r }->@*;
             $e->{'reason'} = $r;
             last;
         }
     }
-    return { 'ds' => $dscontents, 'rfc822' => $emailsteak->[1] };
+    return { 'ds' => $dscontents, 'rfc822' => $emailparts->[1] };
 }
 
 1;
@@ -129,9 +122,8 @@ Sisimai::Lhost::McAfee - bounce mail parser class for C<McAfee Email Appliance>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::McAfee parses a bounce email which created by
-C<McAfee Email Appliance>.
-Methods in the module are called from only Sisimai::Message.
+Sisimai::Lhost::McAfee parses a bounce email which created by C<McAfee Email Appliance>. Methods in
+the module are called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
@@ -141,10 +133,10 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::McAfee->description;
 
-=head2 C<B<make(I<header data>, I<reference to body string>)>>
+=head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<make()> method parses a bounced email and return results as a array reference.
-See Sisimai::Message for more details.
+C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
+for more details.
 
 =head1 AUTHOR
 
@@ -152,7 +144,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2021,2023 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
