@@ -5,12 +5,12 @@ use strict;
 use warnings;
 
 sub description { 'Unknown MTA #5' }
-sub make {
+sub inquire {
     # Detect an error from Unknown MTA #5
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [Undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to parse or the arguments are missing
     # @since v4.13.0
     my $class = shift;
     my $mhead = shift // return undef;
@@ -24,24 +24,23 @@ sub make {
         #       Mail Delivery Subsystem
         for my $f ( split(' ', $mhead->{'from'}) ) {
             # Check each element of From: header
-            next unless Sisimai::MIME->is_mimeencoded(\$f);
-            $match++ if rindex(Sisimai::MIME->mimedecode([$f]), 'Mail Delivery Subsystem') > -1;
+            next unless Sisimai::RFC2045->is_encoded(\$f);
+            $match++ if rindex(Sisimai::RFC2045->decodeH([$f]), 'Mail Delivery Subsystem') > -1;
             last;
         }
     }
 
-    if( Sisimai::MIME->is_mimeencoded(\$mhead->{'subject'}) ) {
+    if( Sisimai::RFC2045->is_encoded(\$mhead->{'subject'}) ) {
         # Subject: =?iso-2022-jp?B?UmV0dXJuZWQgbWFpbDogVXNlciB1bmtub3du?=
-        $plain = Sisimai::MIME->mimedecode([$mhead->{'subject'}]);
+        $plain = Sisimai::RFC2045->decodeH([$mhead->{'subject'}]);
         $match++ if rindex($plain, 'Mail Delivery Subsystem') > -1;
     }
     return undef if $match < 2;
 
     state $indicators = __PACKAGE__->INDICATORS;
-    state $rebackbone = qr|^Content-Type:[ ]message/rfc822|m;
+    state $boundaries = ['Content-Type: message/rfc822'];
     state $startingof = { 'message' => ['Content-Type: message/delivery-status'] };
 
-    require Sisimai::RFC1894;
     my $fieldtable = Sisimai::RFC1894->FIELDTABLE;
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
     my $readcursor = 0;     # (Integer) Points the current cursor position
@@ -49,15 +48,14 @@ sub make {
     my $v = undef;
     my $p = '';
 
-    # Pick the second message/rfc822 part because the format of email-x5-*.eml
-    # is nested structure
-    my $prefillets = [split($rebackbone, $$mbody, 2)];
-       $prefillets->[1] =~ s/\A.+?\n\n//ms;
-    my $emailsteak = Sisimai::RFC5322->fillet(\$prefillets->[1], $rebackbone);
+    # Pick the second message/rfc822 part because the format of email-x5-*.eml is nested structure
+    my $cutsbefore      = [split($boundaries->[0], $$mbody, 2)];
+       $cutsbefore->[1] = substr($cutsbefore->[1], index($cutsbefore->[1], "\n\n") + 2,);
+    my $emailparts      = Sisimai::RFC5322->part(\$cutsbefore->[1], $boundaries);
 
-    for my $e ( split("\n", $emailsteak->[0]) ) {
-        # Read error messages and delivery status lines from the head of the email
-        # to the previous line of the beginning of the original message.
+    for my $e ( split("\n", $emailparts->[0]) ) {
+        # Read error messages and delivery status lines from the head of the email to the previous
+        # line of the beginning of the original message.
         unless( $readcursor ) {
             # Beginning of the bounce message or message/delivery-status part
             $readcursor |= $indicators->{'deliverystatus'} if index($e, $startingof->{'message'}->[0]) == 0;
@@ -102,8 +100,8 @@ sub make {
         } else {
             # Continued line of the value of Diagnostic-Code field
             next unless index($p, 'Diagnostic-Code:') == 0;
-            next unless $e =~ /\A[ \t]+(.+)\z/;
-            $v->{'diagnosis'} .= ' '.$1;
+            next unless index($e, ' ') == 0;
+            $v->{'diagnosis'} .= ' '.Sisimai::String->sweep($e);
         }
     } continue {
         # Save the current line for the next loop
@@ -112,7 +110,7 @@ sub make {
     return undef unless $recipients;
 
     $_->{'diagnosis'} ||= Sisimai::String->sweep($_->{'diagnosis'}) for @$dscontents;
-    return { 'ds' => $dscontents, 'rfc822' => $emailsteak->[1] };
+    return { 'ds' => $dscontents, 'rfc822' => $emailparts->[1] };
 }
 
 1;
@@ -130,8 +128,8 @@ Sisimai::Lhost::X5 - bounce mail parser class for unknown MTA #5.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::X5 parses a bounce email which created by Unknown MTA #5.
-Methods in the module are called from only Sisimai::Message.
+Sisimai::Lhost::X5 parses a bounce email which created by Unknown MTA #5. Methods in the module are
+called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
@@ -141,10 +139,10 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::X5->description;
 
-=head2 C<B<make(I<header data>, I<reference to body string>)>>
+=head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<make()> method parses a bounced email and return results as a array reference.
-See Sisimai::Message for more details.
+C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
+for more details.
 
 =head1 AUTHOR
 
@@ -152,7 +150,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2015-2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2015-2021,2023 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
