@@ -4,17 +4,13 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-state $Indicators = __PACKAGE__->INDICATORS;
-state $ReBackbone = qr|^--- Below this line is a copy of the message[.]|m;
-state $StartingOf = { 'message' => ['Sorry, we were unable to deliver your message'] };
-
 sub description { 'Yahoo! MAIL: https://www.yahoo.com' }
-sub make {
+sub inquire {
     # Detect an error from Yahoo! MAIL
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [Undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to parse or the arguments are missing
     # @since v4.1.3
     my $class = shift;
     my $mhead = shift // return undef;
@@ -26,21 +22,26 @@ sub make {
     # X-Originating-IP: [192.0.2.9]
     return undef unless $mhead->{'x-ymailisg'};
 
+    require Sisimai::SMTP::Command;
+    state $indicators = __PACKAGE__->INDICATORS;
+    state $boundaries = ['--- Below this line is a copy of the message.'];
+    state $startingof = { 'message' => ['Sorry, we were unable to deliver your message'] };
+
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $ReBackbone);
+    my $emailparts = Sisimai::RFC5322->part($mbody, $boundaries);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $v = undef;
 
-    for my $e ( split("\n", $emailsteak->[0]) ) {
-        # Read error messages and delivery status lines from the head of the email
-        # to the previous line of the beginning of the original message.
+    for my $e ( split("\n", $emailparts->[0]) ) {
+        # Read error messages and delivery status lines from the head of the email to the previous
+        # line of the beginning of the original message.
         unless( $readcursor ) {
             # Beginning of the bounce message or message/delivery-status part
-            $readcursor |= $Indicators->{'deliverystatus'} if index($e, $StartingOf->{'message'}->[0]) == 0;
+            $readcursor |= $indicators->{'deliverystatus'} if index($e, $startingof->{'message'}->[0]) == 0;
             next;
         }
-        next unless $readcursor & $Indicators->{'deliverystatus'};
+        next unless $readcursor & $indicators->{'deliverystatus'};
         next unless length $e;
 
         # Sorry, we were unable to deliver your message to the following address.
@@ -49,14 +50,14 @@ sub make {
         # Remote host said: 550 5.1.1 <kijitora@example.org>... User Unknown [RCPT_TO]
         $v = $dscontents->[-1];
 
-        if( $e =~ /\A[<](.+[@].+)[>]:[ \t]*\z/ ) {
+        if( index($e, '<') == 0 && Sisimai::String->aligned(\$e, ['<', '@', '>:']) ) {
             # <kijitora@example.org>:
             if( $v->{'recipient'} ) {
                 # There are multiple recipient addresses in the message body.
                 push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
                 $v = $dscontents->[-1];
             }
-            $v->{'recipient'} = $1;
+            $v->{'recipient'} = Sisimai::Address->s3s4(substr($e, 0, index($e, '>:')));
             $recipients++;
 
         } else {
@@ -65,7 +66,7 @@ sub make {
                 $v->{'diagnosis'} = $e;
 
                 # Get SMTP command from the value of "Remote host said:"
-                $v->{'command'} = $1 if $e =~ /\[([A-Z]{4}).*\]\z/;
+                $v->{'command'} = Sisimai::SMTP::Command->find($e);
             } else {
                 # <mailboxfull@example.jp>:
                 # Remote host said:
@@ -74,9 +75,9 @@ sub make {
                 if( $v->{'diagnosis'} eq 'Remote host said:' ) {
                     # Remote host said:
                     # 550 5.2.2 <mailboxfull@example.jp>... Mailbox Full
-                    if( $e =~ /\[([A-Z]{4}).*\]\z/ ) {
+                    if( my $cv = Sisimai::SMTP::Command->find($e) ) {
                         # [RCPT_TO]
-                        $v->{'command'} = $1;
+                        $v->{'command'} = $cv;
 
                     } else {
                         # 550 5.2.2 <mailboxfull@example.jp>... Mailbox Full
@@ -94,9 +95,9 @@ sub make {
     for my $e ( @$dscontents ) {
         $e->{'diagnosis'} =~ y/\n/ /;
         $e->{'diagnosis'} =  Sisimai::String->sweep($e->{'diagnosis'});
-        $e->{'command'} ||=  'RCPT' if $e->{'diagnosis'} =~ /[<].+[@].+[>]/;
+        $e->{'command'} ||=  'RCPT' if Sisimai::String->aligned(\$e->{'diagnosis'}, ['<', '@', '>']);
     }
-    return { 'ds' => $dscontents, 'rfc822' => $emailsteak->[1] };
+    return { 'ds' => $dscontents, 'rfc822' => $emailparts->[1] };
 }
 
 1;
@@ -114,8 +115,8 @@ Sisimai::Lhost::Yahoo - bounce mail parser class for C<Yahoo! MAIL>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::Yahoo parses a bounce email which created by C<Yahoo! MAIL>.
-Methods in the module are called from only Sisimai::Message.
+Sisimai::Lhost::Yahoo parses a bounce email which created by C<Yahoo! MAIL>. Methods in the module
+are called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
@@ -125,10 +126,10 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::Yahoo->description;
 
-=head2 C<B<make(I<header data>, I<reference to body string>)>>
+=head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<make()> method parses a bounced email and return results as a array reference.
-See Sisimai::Message for more details.
+C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
+for more details.
 
 =head1 AUTHOR
 
@@ -136,7 +137,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2021,2023 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
