@@ -17,9 +17,11 @@ sub match {
     state $index = [
         'connection timed out',
         'could not find a gateway for',
+        'delivery attempts will continue to be',
         'delivery time expired',
         'failed to deliver to domain ',
         'giving up on',
+        'have been failing for a long time',
         'has been delayed',
         'it has not been collected after',
         'message expired after sitting in queue for',
@@ -38,7 +40,7 @@ sub match {
 
 sub true {
     # Delivery expired due to connection failure or network error
-    # @param    [Sisimai::Data] argvs   Object to be detected the reason
+    # @param    [Sisimai::Fact] argvs   Object to be detected the reason
     # @return   [Integer]               1: is expired
     #                                   0: is not expired
     # @see      http://www.ietf.org/rfc/rfc2822.txt
@@ -61,11 +63,11 @@ Sisimai::Reason::Expired - Bounce reason is C<expired> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::Expired checks the bounce reason is C<expired> or not. This
-class is called only Sisimai::Reason class.
+Sisimai::Reason::Expired checks the bounce reason is C<expired> or not. This class is called only
+Sisimai::Reason class.
 
-This is the error that delivery time has expired due to connection failure or
-network error and the message you sent has been in the queue for long time.
+This is the error that delivery time has expired due to connection failure or network error and the
+message you sent has been in the queue for long time.
 
 =head1 CLASS METHODS
 
@@ -81,10 +83,10 @@ C<match()> returns 1 if the argument matched with patterns defined in this class
 
     print Sisimai::Reason::Expired->match('400 Delivery time expired');   # 1
 
-=head2 C<B<true(I<Sisimai::Data>)>>
+=head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<expired>. The argument must be
-Sisimai::Data object and this method is called only from Sisimai::Reason class.
+C<true()> returns 1 if the bounce reason is C<expired>. The argument must be Sisimai::Fact object
+and this method is called only from Sisimai::Reason class.
 
 =head1 AUTHOR
 
@@ -92,7 +94,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2020,2021 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
