@@ -2,6 +2,7 @@ package Sisimai::Reason::HostUnknown;
 use feature ':5.10';
 use strict;
 use warnings;
+use Sisimai::String;
 
 sub text  { 'hostunknown' }
 sub description { "Delivery failed due to a domain part of a recipient's email address does not exist" }
@@ -31,34 +32,36 @@ sub match {
         'unroutable address',
         'unrouteable address',
     ];
-    state $regex = qr/553[ ][^ ]+[ ]does[ ]not[ ]exist/;
+    state $pairs = [['553 ', ' does not exist']];
+
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
-    return 1 if $argv1 =~ $regex;
+    return 1 if grep { Sisimai::String->aligned(\$argv1, $_) } @$pairs;
     return 0;
 }
 
 sub true {
     # Whether the host is unknown or not
-    # @param    [Sisimai::Data] argvs   Object to be detected the reason
+    # @param    [Sisimai::Fact] argvs   Object to be detected the reason
     # @return   [Integer]               1: is unknown host
     #           [Integer]               0: is not unknown host.
     # @since v4.0.0
     # @see http://www.ietf.org/rfc/rfc2822.txt
     my $class = shift;
     my $argvs = shift // return undef;
-    return 1 if $argvs->reason eq 'hostunknown';
+    return 1 if $argvs->{'reason'} eq 'hostunknown';
 
-    my $statuscode = $argvs->deliverystatus // '';
-    my $diagnostic = lc $argvs->diagnosticcode // '';
+    my $statuscode = $argvs->{'deliverystatus'}    // '';
+    my $issuedcode = lc $argvs->{'diagnosticcode'} // '';
 
     if( (Sisimai::SMTP::Status->name($statuscode) || '') eq 'hostunknown' ) {
         # Status: 5.1.2
         # Diagnostic-Code: SMTP; 550 Host unknown
         require Sisimai::Reason::NetworkError;
-        return 1 unless Sisimai::Reason::NetworkError->match($diagnostic);
+        return 1 unless Sisimai::Reason::NetworkError->match($issuedcode);
+
     } else {
         # Check the value of Diagnosic-Code: header with patterns
-        return 1 if __PACKAGE__->match($diagnostic);
+        return 1 if __PACKAGE__->match($issuedcode);
     }
     return 0;
 }
@@ -79,14 +82,13 @@ Sisimai::Reason::HostUnknown - Bounce reason is C<hostunknown> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::HostUnknown checks the bounce reason is C<hostunknown> or not.
-This class is called only Sisimai::Reason class.
+Sisimai::Reason::HostUnknown checks the bounce reason is C<hostunknown> or not. This class is called
+only Sisimai::Reason class.
 
-This is the error that a domain part (Right hand side of @ sign) of a
-recipient's email address does not exist. In many case, the domain part is
-misspelled, or the domain name has been expired. Sisimai will set C<hostunknown>
-to the reason of email bounce if the value of Status: field in a bounce mail is
-C<5.1.2>.
+This is the error that a domain part (Right hand side of @ sign) of a recipient's email address does
+not exist. In many case, the domain part is misspelled, or the domain name has been expired. Sisimai
+will set C<hostunknown> to the reason of email bounce if the value of Status: field in a bounce mail
+is C<5.1.2>.
 
     Your message to the following recipients cannot be delivered:
 
@@ -107,10 +109,10 @@ C<match()> returns 1 if the argument matched with patterns defined in this class
 
     print Sisimai::Reason::HostUnknown->match('550 5.2.1 Host Unknown');   # 1
 
-=head2 C<B<true(I<Sisimai::Data>)>>
+=head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<hostunknown>. The argument must be
-Sisimai::Data object and this method is called only from Sisimai::Reason class.
+C<true()> returns 1 if the bounce reason is C<hostunknown>. The argument must be Sisimai::Fact object
+and this method is called only from Sisimai::Reason class.
 
 =head1 AUTHOR
 
@@ -118,7 +120,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2018,2020,2021 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018,2020,2021,2023 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
