@@ -66,7 +66,7 @@ sub match {
 
 sub true {
     # The envelope recipient's mailbox is full or not
-    # @param    [Sisimai::Data] argvs   Object to be detected the reason
+    # @param    [Sisimai::Fact] argvs   Object to be detected the reason
     # @return   [Integer]               1: is mailbox full
     #                                   0: is not mailbox full
     # @since v4.0.0
@@ -74,16 +74,16 @@ sub true {
     my $class = shift;
     my $argvs = shift // return undef;
 
-    return undef unless $argvs->deliverystatus;
-    return 1 if $argvs->reason eq 'mailboxfull';
+    return undef unless $argvs->{'deliverystatus'};
+    return 1 if $argvs->{'reason'} eq 'mailboxfull';
 
     # Delivery status code points "mailboxfull".
     # Status: 4.2.2
     # Diagnostic-Code: SMTP; 450 4.2.2 <***@example.jp>... Mailbox Full
-    return 1 if (Sisimai::SMTP::Status->name($argvs->deliverystatus) || '') eq 'mailboxfull';
+    return 1 if (Sisimai::SMTP::Status->name($argvs->{'deliverystatus'}) || '') eq 'mailboxfull';
 
     # Check the value of Diagnosic-Code: header with patterns
-    return 1 if __PACKAGE__->match(lc $argvs->diagnosticcode);
+    return 1 if __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
     return 0;
 }
 
@@ -103,12 +103,11 @@ Sisimai::Reason::MailboxFull - Bounce reason is C<mailboxfull> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::MailboxFull checks the bounce reason is C<mailboxfull> or not.
-This class is called only Sisimai::Reason class.
+Sisimai::Reason::MailboxFull checks the bounce reason is C<mailboxfull> or not. This class is called
+only Sisimai::Reason class.
 
-This is the error that a recipient's mailbox is full. Sisimai will set 
-C<mailboxfull> to the reason of email bounce if the value of Status: field in a
-bounce email is C<4.2.2> or C<5.2.2>.
+This is the error that a recipient's mailbox is full. Sisimai will set C<mailboxfull> to the reason
+of email bounce if the value of Status: field in a bounce email is C<4.2.2> or C<5.2.2>.
 
     Action: failed
     Status: 5.2.2
@@ -128,10 +127,10 @@ C<match()> returns 1 if the argument matched with patterns defined in this class
 
     print Sisimai::Reason::MailboxFull->match('400 4.2.3 Mailbox full');   # 1
 
-=head2 C<B<true(I<Sisimai::Data>)>>
+=head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<mailboxfull>. The argument must be
-Sisimai::Data object and this method is called only from Sisimai::Reason class.
+C<true()> returns 1 if the bounce reason is C<mailboxfull>. The argument must be Sisimai::Fact object
+and this method is called only from Sisimai::Reason class.
 
 =head1 AUTHOR
 
@@ -139,7 +138,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018,2020,2021 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
